| Title: | Wrapper for 'Visidata', an Interactive Multitool for Tabular Data |
|---|---|
| Description: | Open any data frame with 'visidata', a terminal-based spreadsheet application <https://www.visidata.org>. |
| Authors: | Paul Klemm [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-5985-1737>), Saul Pwanson [aut], Matthew Mark Strasiotto [ctb] |
| Maintainer: | Paul Klemm <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-27 09:18:27 UTC |
| Source: | https://github.com/paulklemm/rvisidata |
This function checks if visidata is installed on the system. If not, it stops the execution and prompts the user to install visidata.
check_vd()check_vd()
No return value. If visidata is not installed, the function stops execution.
Get visidata command depedning on the TMUX settings
get_vd_cmd()get_vd_cmd()
visidata command as string
This function opens a dataframe in visidata. It first checks if jsonlite is installed, and if so, it uses jsonlite to write the dataframe to a temporary json file. If jsonlite is not installed, it writes the dataframe to a temporary csv file. It then opens the temporary file in visidata.
vd(dat)vd(dat)
dat |
The dataframe to open in visidata. |
The original dataframe, invisibly.